# +=========================================================================+
# || Config::Any::CfgPerl                                                  ||
# ||                                                                       ||
# || Load CfgPerl config files                                             ||
# ||                                                                       ||
# || Copyright (C) 2009 by Christian Kuelker                               ||
# ||                                                                       ||
# +=========================================================================+

package Config::Any::CfgPerl;

use strict;
use warnings;

use base 'Config::Any::Base';
use Carp qw(croak);
use English qw( -no_match_vars);

use vars qw($cfg);    ## no critic
use version; our $VERSION = qv('0.0.1');

my %cache;

# +=========================================================================+
# ||                                                                       ||
# +=========================================================================+
sub extensions {
    return qw( cfgperl );
}

# +=========================================================================+
# ||                                                                       ||
# +=========================================================================+
sub load {
    my $class = shift;
    my $file  = shift;
    my $ret;
    my $msg = "While processing [$file], the file can not be";

    if ( not my $ret = do $file) {    # $r = return
        if ($EVAL_ERROR) {
            croak "$msg parsed! $@";
        }
        if ( not defined $ret ) {
            croak "$msg sourced! $!";
        }
        if ( not $ret ) {
            croak "$msg executed! $cfg";
        }
    }

    $cache{$file} = $cfg;

    return $cfg;
}

=pod

=head1 NAME

Config::Any::CfgPerl - Load CfgPerl config files

=head1 DESCRIPTION

Loads CfgPerl files. Example:

    $cfg = {
        name => 'TestApp',
        'Controller::Foo' => {
            foo => 'bar'
        },
        'Model::Baz' => {
            qux => 'xyzzy'
        }
    }

    my @array = qw( abc def ghi jkl );
    foreach my $c (@array){
        $cfg->{$c} = 'some auto calc value';
    }

    1;

The difference between Config::Any::CfgPerl and Config::Any::Perl is that
Config::Any::Perl expects one hash reference in the configuration files where
as Config::Any::CfgPerl expects the definition of $cfg as a hash reference. The
benefit of using $cfg is that more sofisticated calculations can took place to
gain the value of $cfg.


=head1 METHODS

=head2 extensions( )

return an array of valid extensions (C<cfgperl>).

=head2 load( $file )

Attempts to load C<$file> as a CfgPerl file.


=head1 AUTHOR

Christian Kuelker E<lt>christian.kuelker@cipworx.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2009 by Christian Kuelker

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=over 4

=item * L<Catalyst>

=item * L<Config::Any>

=back

=cut

1;
